summary refs log tree commit diff
path: root/lib/lufa/Demos/Device/ClassDriver/DualVirtualSerial
diff options
context:
space:
mode:
authorDean Camera <dean@fourwalledcubicle.com>2018-06-17 16:06:07 +1000
committerskullydazed <skullydazed@users.noreply.github.com>2018-09-11 12:52:57 -0700
commitdf8e417032bace12d69b5d75aebf257ea5dadb86 (patch)
tree52ab88e56f9b905e2df3485bb79e6031872c28b9 /lib/lufa/Demos/Device/ClassDriver/DualVirtualSerial
parentc7e1b53913707487b0218b984367d32fb4466aaa (diff)
Fix mismatched aliased event and event stub function prototypes.
Diffstat (limited to 'lib/lufa/Demos/Device/ClassDriver/DualVirtualSerial')
-rw-r--r--lib/lufa/Demos/Device/ClassDriver/DualVirtualSerial/DualVirtualSerial.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/lib/lufa/Demos/Device/ClassDriver/DualVirtualSerial/DualVirtualSerial.c b/lib/lufa/Demos/Device/ClassDriver/DualVirtualSerial/DualVirtualSerial.c
index 9a7ff4725e..0210ff55c0 100644
--- a/lib/lufa/Demos/Device/ClassDriver/DualVirtualSerial/DualVirtualSerial.c
+++ b/lib/lufa/Demos/Device/ClassDriver/DualVirtualSerial/DualVirtualSerial.c
@@ -231,12 +231,14 @@ void EVENT_CDC_Device_ControLineStateChanged(USB_ClassInfo_CDC_Device_t *const C
 	*/
 	bool HostReady = (CDCInterfaceInfo->State.ControlLineStates.HostToDevice & CDC_CONTROL_LINE_OUT_DTR) != 0;
 
+	(void)HostReady;
+
 	if (CDCInterfaceInfo == &VirtualSerial1_CDC_Interface)
 	{
 		// CDC interface 1's host is ready to send/receive data
 	}
 	else
 	{
 		// CDC interface 2's host is ready to send/receive data
 	}
 }
@@ -231,12 +231,14 @@ void EVENT_CDC_Device_ControLineStateChanged(USB_ClassInfo_CDC_Device_t *const C
 	if (CDCInterfaceInfo == &VirtualSerial1_CDC_Interface)
 	{
-		// CDC interface 1's host is ready to send/receive data
+		// CDC interface 1's host is ready to send/receive data if HostReady is true
 	}
 	else
@@ -231,12 +231,14 @@ void EVENT_CDC_Device_ControLineStateChanged(USB_ClassInfo_CDC_Device_t *const C
 	else
 	{
-		// CDC interface 2's host is ready to send/receive data
+		// CDC interface 2's host is ready to send/receive data if HostReady is true
 	}
 }